@@ -1,16 +1,18 @@
 from .build import build
 from .commit import commit
-from .test import test
+from .tests import tests
 from .session import session
 import click
+from launchable.utils.click import GroupWithAlias
 
 
-@click.group()
+@click.group(cls=GroupWithAlias)
 def record():
     pass
 
 
 record.add_command(build)
 record.add_command(commit)
-record.add_command(test)
+record.add_command(tests)
+record.add_alias('test', tests)    # for backward compatibility
 record.add_command(session)
